
# Type: has phenotype


holds between a biological entity and a phenotype, where a phenotype is construed broadly as any kind of quality of an organism part, a collection of these qualities, or a change in quality or qualities (e.g. abnormally increased temperature).

URI: [biolink:has_phenotype](https://w3id.org/biolink/vocab/has_phenotype)


## Domain and Range

[BiologicalEntity](BiologicalEntity.md) ->  <sub>0..*</sub> [PhenotypicFeature](PhenotypicFeature.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [AnatomicalEntity](AnatomicalEntity.md)
 * [BiologicalEntity](BiologicalEntity.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [Carbohydrate](Carbohydrate.md)
 * [Case](Case.md)
 * [Cell](Cell.md)
 * [CellLine](CellLine.md)
 * [CellularComponent](CellularComponent.md)
 * [ChemicalExposure](ChemicalExposure.md)
 * [ChemicalSubstance](ChemicalSubstance.md)
 * [CodingSequence](CodingSequence.md)
 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [Drug](Drug.md)
 * [DrugExposure](DrugExposure.md)
 * [Exon](Exon.md)
 * [ExposureEvent](ExposureEvent.md)
 * [Gene](Gene.md)
 * [GeneFamily](GeneFamily.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [Genome](Genome.md)
 * [GenomicEntity](GenomicEntity.md)
 * [Genotype](Genotype.md)
 * [GrossAnatomicalStructure](GrossAnatomicalStructure.md)
 * [Haplotype](Haplotype.md)
 * [IndividualOrganism](IndividualOrganism.md)
 * [LifeStage](LifeStage.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [Metabolite](Metabolite.md)
 * [MicroRNA](MicroRNA.md)
 * [MolecularActivity](MolecularActivity.md)
 * [MolecularEntity](MolecularEntity.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [OrganismalEntity](OrganismalEntity.md)
 * [Pathway](Pathway.md)
 * [PhenotypicFeature](PhenotypicFeature.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [SequenceVariant](SequenceVariant.md)
 * [Transcript](Transcript.md)
 * [Treatment](Treatment.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002200 |
| **In Subsets:** | | translator_minimal |

